/* Scoreboard Version 7.0 - FINAL
 This is the code for a Softball scoreboard keeping double 
 digit score for visitor and home, innings, and outs.
 Using the IR Remote library from:
 --------------------------------------------------------------- 
 IR Remote
 http://arduino-info.wikispaces.com/IR-RemoteControl
 based on code by Ken Shirriff - http://arcfn.com
 Get Library at: https://github.com/shirriff/Arduino-IRremote
 Unzip folder into Libraries. 
 RENAME folder "IRremote"
 
 Also very helpful for use of the IR remote and the shift registers:  
 http://www.yourwarrantyisvoid.com/2012/07/10/hardware-remote-control-your-arduino/
 This program controls a 7 segment LED with a Shift Register and IR remote
 --------------------------------------------------------------- 
 MY STUFF: 
 The scoreboard uses 5 Seven-Segment LEDs that are made up of LED strips 
 cut into 6 LED long segments and made up to look like 
 7-segment LEDs.  They are controlled by an Arduino Mega with 5 shift 
 registers using 3 pins each.
 Outs are three LED bunches consisting of 4 columns of 3 LED long segments
 of Red LEDs in a square pattern: 
 `           0 O O O    0 0 O O    0 0 O O
 OUTS:       0 O O O    0 0 O O    0 0 O O
 `           0 O O O    0 0 O O    0 0 O O
 Each "out" square is connected together in series, utilizing 1 arduino pin 
 for each out.
 ----------------------------------------------------------------
 VISITOR  INNING    HOME 
 `_   _      _     _   _         
 |_| |_|    |_|   |_| |_|
 |_| |_|    |_|   |_| |_|
 tens ones  inn  tens ones
 `           Outs: O O O
 ----------------------------------------------------------------
 The LED strips use 12V for power and the Arduino cannot power that.
 A 12V power supply is hooked up directly to +12v of each strip.
 Each arduino pin goes to a TIP-120 which in turn allows the current 
 to flow through to each individual LED strip.
 `                 ________
 `                |  TIP   |
 `                |  120   |
 `                |________|
 `                ||  ||  ||
 `                ||  ||  ||
 `To Arduino Pin--||  ||  ||---to GROUND     
 '                    |                     (+12V)_____________________
 '                    |---To LED Segment_______________|__0___0___0____LED Segment
 */
/* Five (5) Shift Registers are used, 74HC595.
 Letters indicate segment of 7-Segment LED.
 `__A__
 |     |
 F     B
 |__G__|
 |     |
 E     C
 |__D__|
 
 Pin Designation for the shift Register as follows: 
 1.  B    16.  +5V    (X = not used)
 2.  C    15.  A
 3.  D    14.  Data
 4.  E    13.  GND
 5.  F    12.  Latch
 6.  G    11.  Clock
 7.  X    10.  +5V
 8.  GND   9.  X
 */
/* IR Receiver Pins
 `                     _____
 `                    |     |
 `                    |  IR |
 `                    |_____|
 `                    |  |  |
 `                    |  |  |
 `To Arduino Pin#11 --|  |  |---to +5V Power     
 '                       |                    
 '                       |---To GROUND
 */
#include <IRremote.h>

int RECV_PIN = 11;
IRrecv irrecv(RECV_PIN);
decode_results results;
// Assign Shift Register Pins for Data, latch and Clock
int dataPinVT = 22; //Visitor Tens Shift Register
int latchPinVT = 29;
int clkPinVT = 31;
int dataPinVO = 28; //Visitor Ones Shift Register
int latchPinVO = 26;
int clkPinVO = 24;
int dataPini = 23; //Inning Shift Register
int latchPini = 30;
int clkPini = 32;
int dataPinHT = 47; //Home Tens Shift Register
int latchPinHT = 49;
int clkPinHT = 51;
int dataPinHO = 41; //Home Ones Shift Register
int latchPinHO = 43;
int clkPinHO = 45;
// Assign pins for outs
int out1 = 53;
int out2 = 27;
int out3 = 25;
// Initialize what will be displayed
int visitorTensDisplay = 0;
int visitorOnesDisplay = 0;
int inningDisplay = 0;
int homeTensDisplay = 0;
int homeOnesDisplay = 0;

// Set counters to zero for displays
int visitorCount = 0; 
int inningCount = 1;  
int homeCount = 0;  
int outCount = 0;  
// Declare pins as outputs
void setup()
{
  pinMode(latchPinVT, OUTPUT);
  pinMode(clkPinVT, OUTPUT);
  pinMode(dataPinVT, OUTPUT);
  pinMode(latchPinVO, OUTPUT);
  pinMode(clkPinVO, OUTPUT);
  pinMode(dataPinVO, OUTPUT);  
  pinMode(latchPini, OUTPUT);
  pinMode(clkPini, OUTPUT);
  pinMode(dataPini, OUTPUT); 
  pinMode(latchPinHT, OUTPUT);
  pinMode(clkPinHT, OUTPUT);
  pinMode(dataPinHT, OUTPUT); 
  pinMode(latchPinHO, OUTPUT);
  pinMode(clkPinHO, OUTPUT);
  pinMode(dataPinHO, OUTPUT);
  pinMode(out1, OUTPUT);
  pinMode(out2, OUTPUT);
  pinMode(out3, OUTPUT);
  // Enable the IR stuff
  Serial.begin(9600);
  irrecv.enableIRIn(); // Start the receiver
  // Initalize the displays

  visitorTensDisplay=127;
  visitorOnesDisplay=127;  
  inningDisplay=127;
  homeTensDisplay=127;
  homeOnesDisplay=127;
  outCount=3;  

  // Not sure, I think this maps the seven segments
  // VISITOR TENS AND ONES
  digitalWrite(latchPinVT, LOW);
  shiftOut(dataPinVT,clkPinVT,MSBFIRST,visitorTensDisplay);  
  digitalWrite(latchPinVT, HIGH);

  digitalWrite(latchPinVO, LOW);
  shiftOut(dataPinVO,clkPinVO,MSBFIRST,visitorOnesDisplay);  
  digitalWrite(latchPinVO, HIGH); 
  // INNING DIGIT
  digitalWrite(latchPini, LOW);
  shiftOut(dataPini,clkPini,MSBFIRST,inningDisplay);
  digitalWrite(latchPini, HIGH);
  // HOME TENS AND ONES
  digitalWrite(latchPinHT, LOW);
  shiftOut(dataPinHT,clkPinHT,MSBFIRST,homeTensDisplay);
  digitalWrite(latchPinHT, HIGH);

  digitalWrite(latchPinHO, LOW);
  shiftOut(dataPinHO,clkPinHO,MSBFIRST,homeOnesDisplay);
  digitalWrite(latchPinHO, HIGH); 
  // OUTS
  digitalWrite(out1, LOW); 
  digitalWrite(out2, LOW);
  digitalWrite(out3, LOW);
}

void loop() {
  // IR stuff: basically decodes the keypress from the remote in a switch case
  if (irrecv.decode(&results)) {

    switch (results.value)  
    {
    case 0xFF11EE:  
      Serial.println("Dog"); 
      break;
    case 0xFF619E:  // POWER  (Resets all all counts to 0)
      for(int i=0; i<3; i++){
        visitorTensDisplay=127;
        visitorOnesDisplay=127;  
        inningDisplay=127;
        homeTensDisplay=127;
        homeOnesDisplay=127;
        digitalWrite(out1, HIGH);
        digitalWrite(out2, HIGH);
        digitalWrite(out3, HIGH);
        delay(1000);
        visitorTensDisplay=0;
        visitorOnesDisplay=0;  
        inningDisplay=0;
        homeTensDisplay=0;
        homeOnesDisplay=0;
        digitalWrite(out1, LOW);
        digitalWrite(out2, LOW);
        digitalWrite(out3, LOW);
        delay(1000); 
      }
      inningCount = 1; 
      visitorCount = 0; 
      homeCount = 0; 
      outCount = 0;  
      Serial.println("Power button"); 
      break;
    case 0xFFA15E:  
      Serial.println("Mute"); 
      break;
    case 0xFF49B6:  
      Serial.println("One"); 
      break;
    case 0xFF6996:  
      Serial.println("Two"); 
      break;
    case 0xFF59A6:  
      Serial.println("Three"); 
      break;
    case 0xFF8976:  
      Serial.println("Four"); 
      break;
    case 0xFFA965:  
      Serial.println("Five"); 
      break;
    case 0xFF9966:  
      Serial.println("Six"); 
      break;
    case 0xFF09F6:  
      Serial.println("Seven"); 
      break;
    case 0xFF29D6:  
      Serial.println("Eight"); 
      break;
    case 0xFF19E6:  
      Serial.println("Nine"); 
      break;
    case 0xFF21DE:  
      Serial.println("Zero"); 
      break;
    case 0xFFE11E:  // UP (increases the visitor count by one)
      visitorCount = visitorCount+1;
      if(visitorCount>99){  // after 99 runs, counter goes back to 0
        visitorCount = 0;     
      }
      Serial.println("Up"); 
      break;
    case 0xFF31CE:  // DOWN (decreases the visitor count by one)
      visitorCount = visitorCount-1; 
      if(visitorCount<0){
        visitorCount = 0;
      } 
      Serial.println("Down"); 
      break;
    case 0xFFF906:  // LEFT  (decreases the home count by one)
      homeCount = homeCount-1;
      if(homeCount<0){
        homeCount=0;
      }  
      Serial.println("Left"); 
      break;
    case 0xFF916E:  // RIGHT  (increases the home count by one)
      homeCount = homeCount+1;
      if(homeCount>99){  // after 99 runs, counter goes back to 0 and no negative counts
        homeCount = 0;     
      } 
      Serial.println("Right"); 
      break;
    case 0xFF7986:  // REVERSE (decreases the inning count by one)
      inningCount=inningCount-1;
      if(inningCount<0){
        inningCount=0;    //inning count can't go below 0
      }
      Serial.println("Reverse"); 
      break;
    case 0xFFB14E:  
      Serial.println("Play"); 
      break;
    case 0xFF51AE:  // >>| (increases the inning count by one)
      inningCount=inningCount+1;
      if(inningCount>9){  // after 9 innings, counter goes back to 1 
        inningCount = 1;     
      } 
      Serial.println("Fast Forward"); 
      break;
    case 0xFF39C6:  
      Serial.println("Menu"); 
      break;
    case 0xFFF10E:  
      Serial.println("Display"); 
      break;
    case 0xFFC936:  
      Serial.println("Band"); 
      break;
    case 0xFFE916:  
      Serial.println("Memory"); 
      break;
    case 0xFFD12E:  //UP (+) (increases the out count by one)
      outCount = outCount+1; 
      if(outCount>3){  // after 3 outs, counter goes back to 0 
        outCount = 0;     
      }  
      Serial.println("Up +"); 
      break;
    case 0xFFD926:  // DOWN (-) (decreases the out count by one)
      outCount = outCount-1; 
      if(outCount<0){ // no negative counts
        outCount=0;
      } 
      Serial.println("Down -"); 
      break;
    case 0xFFB946:  
      Serial.println("Return"); 
      break;
    case 0xFF718E:  
      Serial.println("Radio"); 
      break;        
    }
    delay(100);

    // Out Count Switch-case, when the count equals 0-3, 
    //this tells which lights come on, displays outs 0-3
    switch (outCount){
    case 0:
      digitalWrite(out1, LOW);
      digitalWrite(out2, LOW);
      digitalWrite(out3, LOW);
      break;
    case 1:
      digitalWrite(out1, HIGH);
      digitalWrite(out2, LOW);
      digitalWrite(out3, LOW);
      break;
    case 2:
      digitalWrite(out1, HIGH);
      digitalWrite(out2, HIGH);
      digitalWrite(out3, LOW);
      break;
    case 3:
      digitalWrite(out1, HIGH);
      digitalWrite(out2, HIGH);
      digitalWrite(out3, HIGH);
      break;
    }
    // Inning Count Switch-case, displays Inning from 0-9 
    switch (inningCount){
    case 0:
      inningDisplay = 63;
      break;
    case 1:
      inningDisplay = 6;
      break;
    case 2:
      inningDisplay = 91;
      break;
    case 3:
      inningDisplay = 79;
      break;
    case 4:
      inningDisplay = 102;
      break;
    case 5:
      inningDisplay = 109;
      break;
    case 6:
      inningDisplay = 125;
      break;
    case 7:
      inningDisplay = 7;
      break;
    case 8:
      inningDisplay = 127;
      break;
    case 9:
      inningDisplay = 111;
      break;
    }
    // Visitor Count Switch-case, displays Visitor score from 0-99
    switch (visitorCount){
    case 0:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 63;
      break;
    case 1:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 6;      
      break;
    case 2:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 91;    
      break;
    case 3:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 79;    
      break;
    case 4:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 102;    
      break;
    case 5:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 109;
      break;
    case 6:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 125;
      break;
    case 7:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 7;
      break;
    case 8:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 127;
      break;
    case 9:
      visitorTensDisplay = 0;
      visitorOnesDisplay = 111;
      break;
    case 10:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 63;
      break; 
    case 11:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 6;      
      break;
    case 12:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 91;    
      break;
    case 13:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 79;    
      break;
    case 14:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 102;    
      break;
    case 15:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 109;
      break;
    case 16:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 125;
      break;
    case 17:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 7;
      break;
    case 18:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 127;
      break;
    case 19:
      visitorTensDisplay = 6;
      visitorOnesDisplay = 111;
      break;
    case 20:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 63;
      break; 
    case 21:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 6;      
      break;
    case 22:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 91;    
      break;
    case 23:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 79;    
      break;
    case 24:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 102;    
      break;
    case 25:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 109;
      break;
    case 26:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 125;
      break;
    case 27:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 7;
      break;
    case 28:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 127;
      break;
    case 29:
      visitorTensDisplay = 91;
      visitorOnesDisplay = 111;
      break;
    case 30:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 63;
      break; 
    case 31:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 6;      
      break;
    case 32:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 91;    
      break;
    case 33:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 79;    
      break;
    case 34:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 102;    
      break;
    case 35:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 109;
      break;
    case 36:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 125;
      break;
    case 37:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 7;
      break;
    case 38:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 127;
      break;
    case 39:
      visitorTensDisplay = 79;
      visitorOnesDisplay = 111;
      break;
    case 40:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 63;
      break; 
    case 41:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 6;      
      break;
    case 42:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 91;    
      break;
    case 43:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 79;    
      break;
    case 44:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 102;    
      break;
    case 45:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 109;
      break;
    case 46:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 125;
      break;
    case 47:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 7;
      break;
    case 48:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 127;
      break;
    case 49:
      visitorTensDisplay = 102;
      visitorOnesDisplay = 111;
      break;
    case 50:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 63;
      break; 
    case 51:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 6;      
      break;
    case 52:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 91;    
      break;
    case 53:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 79;    
      break;
    case 54:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 102;    
      break;
    case 55:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 109;
      break;
    case 56:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 125;
      break;
    case 57:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 7;
      break;
    case 58:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 127;
      break;
    case 59:
      visitorTensDisplay = 109;
      visitorOnesDisplay = 111;
      break;
    case 60:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 63;
      break; 
    case 61:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 6;      
      break;
    case 62:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 91;    
      break;
    case 63:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 79;    
      break;
    case 64:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 102;    
      break;
    case 65:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 109;
      break;
    case 66:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 125;
      break;
    case 67:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 7;
      break;
    case 68:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 127;
      break;
    case 69:
      visitorTensDisplay = 125;
      visitorOnesDisplay = 111;
      break;
    case 70:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 63;
      break; 
    case 71:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 6;      
      break;
    case 72:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 91;    
      break;
    case 73:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 79;    
      break;
    case 74:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 102;    
      break;
    case 75:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 109;
      break;
    case 76:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 125;
      break;
    case 77:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 7;
      break;
    case 78:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 127;
      break;
    case 79:
      visitorTensDisplay = 7;
      visitorOnesDisplay = 111;
      break;
    case 80:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 63;
      break; 
    case 81:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 6;      
      break;
    case 82:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 91;    
      break;
    case 83:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 79;    
      break;
    case 84:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 102;    
      break;
    case 85:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 109;
      break;
    case 86:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 125;
      break;
    case 87:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 7;
      break;
    case 88:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 127;
      break;
    case 89:
      visitorTensDisplay = 127;
      visitorOnesDisplay = 111;
      break;
    case 90:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 63;
      break; 
    case 91:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 6;      
      break;
    case 92:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 91;    
      break;
    case 93:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 79;    
      break;
    case 94:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 102;    
      break;
    case 95:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 109;
      break;
    case 96:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 125;
      break;
    case 97:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 7;
      break;
    case 98:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 127;
      break;
    case 99:
      visitorTensDisplay = 111;
      visitorOnesDisplay = 111;
      break;
      // Home Count Switch-case, displays Home score from 0-99
    }
    switch (homeCount){
    case 0:
      homeTensDisplay = 0;
      homeOnesDisplay = 63;
      break;
    case 1:
      homeTensDisplay = 0;
      homeOnesDisplay = 6;      
      break;
    case 2:
      homeTensDisplay = 0;
      homeOnesDisplay = 91;    
      break;
    case 3:
      homeTensDisplay = 0;
      homeOnesDisplay = 79;    
      break;
    case 4:
      homeTensDisplay = 0;
      homeOnesDisplay = 102;    
      break;
    case 5:
      homeTensDisplay = 0;
      homeOnesDisplay = 109;
      break;
    case 6:
      homeTensDisplay = 0;
      homeOnesDisplay = 125;
      break;
    case 7:
      homeTensDisplay = 0;
      homeOnesDisplay = 7;
      break;
    case 8:
      homeTensDisplay = 0;
      homeOnesDisplay = 127;
      break;
    case 9:
      homeTensDisplay = 0;
      homeOnesDisplay = 111;
      break;
    case 10:
      homeTensDisplay = 6;
      homeOnesDisplay = 63;
      break; 
    case 11:
      homeTensDisplay = 6;
      homeOnesDisplay = 6;      
      break;
    case 12:
      homeTensDisplay = 6;
      homeOnesDisplay = 91;    
      break;
    case 13:
      homeTensDisplay = 6;
      homeOnesDisplay = 79;    
      break;
    case 14:
      homeTensDisplay = 6;
      homeOnesDisplay = 102;    
      break;
    case 15:
      homeTensDisplay = 6;
      homeOnesDisplay = 109;
      break;
    case 16:
      homeTensDisplay = 6;
      homeOnesDisplay = 125;
      break;
    case 17:
      homeTensDisplay = 6;
      homeOnesDisplay = 7;
      break;
    case 18:
      homeTensDisplay = 6;
      homeOnesDisplay = 127;
      break;
    case 19:
      homeTensDisplay = 6;
      homeOnesDisplay = 111;
      break;
    case 20:
      homeTensDisplay = 91;
      homeOnesDisplay = 63;
      break; 
    case 21:
      homeTensDisplay = 91;
      homeOnesDisplay = 6;      
      break;
    case 22:
      homeTensDisplay = 91;
      homeOnesDisplay = 91;    
      break;
    case 23:
      homeTensDisplay = 91;
      homeOnesDisplay = 79;    
      break;
    case 24:
      homeTensDisplay = 91;
      homeOnesDisplay = 102;    
      break;
    case 25:
      homeTensDisplay = 91;
      homeOnesDisplay = 109;
      break;
    case 26:
      homeTensDisplay = 91;
      homeOnesDisplay = 125;
      break;
    case 27:
      homeTensDisplay = 91;
      homeOnesDisplay = 7;
      break;
    case 28:
      homeTensDisplay = 91;
      homeOnesDisplay = 127;
      break;
    case 29:
      homeTensDisplay = 91;
      homeOnesDisplay = 111;
      break;
    case 30:
      homeTensDisplay = 79;
      homeOnesDisplay = 63;
      break; 
    case 31:
      homeTensDisplay = 79;
      homeOnesDisplay = 6;      
      break;
    case 32:
      homeTensDisplay = 79;
      homeOnesDisplay = 91;    
      break;
    case 33:
      homeTensDisplay = 79;
      homeOnesDisplay = 79;    
      break;
    case 34:
      homeTensDisplay = 79;
      homeOnesDisplay = 102;    
      break;
    case 35:
      homeTensDisplay = 79;
      homeOnesDisplay = 109;
      break;
    case 36:
      homeTensDisplay = 79;
      homeOnesDisplay = 125;
      break;
    case 37:
      homeTensDisplay = 79;
      homeOnesDisplay = 7;
      break;
    case 38:
      homeTensDisplay = 79;
      homeOnesDisplay = 127;
      break;
    case 39:
      homeTensDisplay = 79;
      homeOnesDisplay = 111;
      break;
    case 40:
      homeTensDisplay = 102;
      homeOnesDisplay = 63;
      break; 
    case 41:
      homeTensDisplay = 102;
      homeOnesDisplay = 6;      
      break;
    case 42:
      homeTensDisplay = 102;
      homeOnesDisplay = 91;    
      break;
    case 43:
      homeTensDisplay = 102;
      homeOnesDisplay = 79;    
      break;
    case 44:
      homeTensDisplay = 102;
      homeOnesDisplay = 102;    
      break;
    case 45:
      homeTensDisplay = 102;
      homeOnesDisplay = 109;
      break;
    case 46:
      homeTensDisplay = 102;
      homeOnesDisplay = 125;
      break;
    case 47:
      homeTensDisplay = 102;
      homeOnesDisplay = 7;
      break;
    case 48:
      homeTensDisplay = 102;
      homeOnesDisplay = 127;
      break;
    case 49:
      homeTensDisplay = 102;
      homeOnesDisplay = 111;
      break;
    case 50:
      homeTensDisplay = 109;
      homeOnesDisplay = 63;
      break; 
    case 51:
      homeTensDisplay = 109;
      homeOnesDisplay = 6;      
      break;
    case 52:
      homeTensDisplay = 109;
      homeOnesDisplay = 91;    
      break;
    case 53:
      homeTensDisplay = 109;
      homeOnesDisplay = 79;    
      break;
    case 54:
      homeTensDisplay = 109;
      homeOnesDisplay = 102;    
      break;
    case 55:
      homeTensDisplay = 109;
      homeOnesDisplay = 109;
      break;
    case 56:
      homeTensDisplay = 109;
      homeOnesDisplay = 125;
      break;
    case 57:
      homeTensDisplay = 109;
      homeOnesDisplay = 7;
      break;
    case 58:
      homeTensDisplay = 109;
      homeOnesDisplay = 127;
      break;
    case 59:
      homeTensDisplay = 109;
      homeOnesDisplay = 111;
      break;
    case 60:
      homeTensDisplay = 125;
      homeOnesDisplay = 63;
      break; 
    case 61:
      homeTensDisplay = 125;
      homeOnesDisplay = 6;      
      break;
    case 62:
      homeTensDisplay = 125;
      homeOnesDisplay = 91;    
      break;
    case 63:
      homeTensDisplay = 125;
      homeOnesDisplay = 79;    
      break;
    case 64:
      homeTensDisplay = 125;
      homeOnesDisplay = 102;    
      break;
    case 65:
      homeTensDisplay = 125;
      homeOnesDisplay = 109;
      break;
    case 66:
      homeTensDisplay = 125;
      homeOnesDisplay = 125;
      break;
    case 67:
      homeTensDisplay = 125;
      homeOnesDisplay = 7;
      break;
    case 68:
      homeTensDisplay = 125;
      homeOnesDisplay = 127;
      break;
    case 69:
      homeTensDisplay = 125;
      homeOnesDisplay = 111;
      break;
    case 70:
      homeTensDisplay = 7;
      homeOnesDisplay = 63;
      break; 
    case 71:
      homeTensDisplay = 7;
      homeOnesDisplay = 6;      
      break;
    case 72:
      homeTensDisplay = 7;
      homeOnesDisplay = 91;    
      break;
    case 73:
      homeTensDisplay = 7;
      homeOnesDisplay = 79;    
      break;
    case 74:
      homeTensDisplay = 7;
      homeOnesDisplay = 102;    
      break;
    case 75:
      homeTensDisplay = 7;
      homeOnesDisplay = 109;
      break;
    case 76:
      homeTensDisplay = 7;
      homeOnesDisplay = 125;
      break;
    case 77:
      homeTensDisplay = 7;
      homeOnesDisplay = 7;
      break;
    case 78:
      homeTensDisplay = 7;
      homeOnesDisplay = 127;
      break;
    case 79:
      homeTensDisplay = 7;
      homeOnesDisplay = 111;
      break;
    case 80:
      homeTensDisplay = 127;
      homeOnesDisplay = 63;
      break; 
    case 81:
      homeTensDisplay = 127;
      homeOnesDisplay = 6;      
      break;
    case 82:
      homeTensDisplay = 127;
      homeOnesDisplay = 91;    
      break;
    case 83:
      homeTensDisplay = 127;
      homeOnesDisplay = 79;    
      break;
    case 84:
      homeTensDisplay = 127;
      homeOnesDisplay = 102;    
      break;
    case 85:
      homeTensDisplay = 127;
      homeOnesDisplay = 109;
      break;
    case 86:
      homeTensDisplay = 127;
      homeOnesDisplay = 125;
      break;
    case 87:
      homeTensDisplay = 127;
      homeOnesDisplay = 7;
      break;
    case 88:
      homeTensDisplay = 127;
      homeOnesDisplay = 127;
      break;
    case 89:
      homeTensDisplay = 127;
      homeOnesDisplay = 111;
      break;
    case 90:
      homeTensDisplay = 111;
      homeOnesDisplay = 63;
      break; 
    case 91:
      homeTensDisplay = 111;
      homeOnesDisplay = 6;      
      break;
    case 92:
      homeTensDisplay = 111;
      homeOnesDisplay = 91;    
      break;
    case 93:
      homeTensDisplay = 111;
      homeOnesDisplay = 79;    
      break;
    case 94:
      homeTensDisplay = 111;
      homeOnesDisplay = 102;    
      break;
    case 95:
      homeTensDisplay = 111;
      homeOnesDisplay = 109;
      break;
    case 96:
      homeTensDisplay = 111;
      homeOnesDisplay = 125;
      break;
    case 97:
      homeTensDisplay = 111;
      homeOnesDisplay = 7;
      break;
    case 98:
      homeTensDisplay = 111;
      homeOnesDisplay = 127;
      break;
    case 99:
      homeTensDisplay = 111;
      homeOnesDisplay = 111;
      break;
    }
    digitalWrite(latchPinVT, LOW);
    shiftOut(dataPinVT,clkPinVT,MSBFIRST,visitorTensDisplay);
    digitalWrite(latchPinVT, HIGH);

    digitalWrite(latchPinVO, LOW);
    shiftOut(dataPinVO,clkPinVO,MSBFIRST,visitorOnesDisplay);
    digitalWrite(latchPinVO, HIGH);

    digitalWrite(latchPini, LOW);
    shiftOut(dataPini,clkPini,MSBFIRST,inningDisplay);
    digitalWrite(latchPini, HIGH); 

    digitalWrite(latchPinHT, LOW);
    shiftOut(dataPinHT,clkPinHT,MSBFIRST,homeTensDisplay);
    digitalWrite(latchPinHT, HIGH);

    digitalWrite(latchPinHO, LOW);
    shiftOut(dataPinHO,clkPinHO,MSBFIRST,homeOnesDisplay);
    digitalWrite(latchPinHO, HIGH);   
    //IR STUFF
    irrecv.resume(); // Receive the next value
  }
}
